@@ -1,4 +1,4 @@
-//  $Id: construo_main.cxx,v 1.26 2003/07/26 11:18:47 grumbel Exp $
+//  $Id: construo_main.cxx,v 1.27 2003/07/28 10:24:00 grumbel Exp $
 //
 //  Construo - A wire-frame construction game
 //  Copyright (C) 2002 Ingo Ruhnke <grumbel@gmx.de>
@@ -25,14 +25,14 @@
 #include "path_manager.hxx"
 #include "construo_error.hxx"
 
-#ifdef USE_X11_DISPLAY
+#if defined(USE_X11_DISPLAY)
 #  include "x11_display.hxx"
 #  include "unix_system.hxx"
-#else 
-#  ifdef USE_GLUT_DISPLAY
-#    include "glut_display.hxx"
-#    include "unix_system.hxx"
-#  endif
+#elif defined(USE_GLUT_DISPLAY)
+#  include "glut_display.hxx"
+#  include "unix_system.hxx"
+#else
+#  error "No Display target defined!"
 #endif
 
 #include "controller.hxx"
