@@ -1,4 +1,4 @@
-//  $Id: controller.cxx,v 1.11 2003/07/26 14:43:56 grumbel Exp $
+//  $Id: controller.cxx,v 1.12 2003/07/27 18:46:11 grumbel Exp $
 //
 //  Construo - A wire-frame construction game
 //  Copyright (C) 2002 Ingo Ruhnke <grumbel@gmx.de>
@@ -115,7 +115,7 @@ Controller::update ()
       else
         {
           delta /= 5.0f/20.0f;
-          min_skip = 0.02;//; 0.007f;
+          min_skip = 0.02; // 0.02
         }
       
       float i = 0.0f;
