@@ -1,4 +1,4 @@
-//  $Id: rect_collider.cxx,v 1.8 2003/01/11 01:35:11 grumbel Exp $
+//  $Id: rect_collider.cxx,v 1.10 2003/07/26 11:18:47 grumbel Exp $
 //
 //  Construo - A wire-frame construction gamee
 //  Copyright (C) 2002 Ingo Ruhnke <grumbel@gmx.de>
@@ -48,7 +48,10 @@ RectCollider::RectCollider (lisp_object_t* cursor)
 }
 
 RectCollider::RectCollider (float x1_, float y1_, float x2_, float y2_)
-  : x1 (x1_), y1 (y1_), x2 (x2_), y2 (y2_)
+  : x1 (Math::min(x1_, x2_)), 
+    y1 (Math::min(y1_, y2_)), 
+    x2 (Math::max(x1_, x2_)), 
+    y2 (Math::max(y1_, y2_))
 {
 }
 
@@ -142,13 +145,19 @@ RectCollider::draw_highlight (GraphicContext* gc)
   gc->draw_rect (x1, y1, x2, y2, Colors::selection_rect);
 }
 
+BoundingBox
+RectCollider::get_bounding_box() const
+{
+  return BoundingBox(x1, y1, x2, y2);
+}
+
 lisp_object_t*
 RectCollider::serialize()
 {
   LispWriter obj ("rect");
   obj.write_vector ("pos1", Vector2d(x1, y1));
   obj.write_vector ("pos2", Vector2d(x2, y2));
-  return obj.get_lisp ();
+  return obj.create_lisp ();
 }
 
 /* EOF */
