@@ -1,6 +1,6 @@
-//  $Id$
+//  $Id: save_gui_manager.cxx,v 1.3 2003/07/26 00:39:31 grumbel Exp $
 //
-//  Pingus - A free Lemmings clone
+//  Construo - A wire-frame construction game
 //  Copyright (C) 2002 Ingo Ruhnke <grumbel@gmx.de>
 //
 //  This program is free software; you can redistribute it and/or
@@ -20,6 +20,7 @@
 #include "gui_file_manager.hxx"
 #include "construo.hxx"
 #include "system_context.hxx"
+#include "root_graphic_context.hxx"
 #include "save_gui_manager.hxx"
 
 SaveGUIManager::SaveGUIManager ()
