@@ -1,4 +1,4 @@
-//  $Id: world.cxx,v 1.33 2003/07/26 11:18:47 grumbel Exp $
+//  $Id: world.cxx,v 1.35 2003/07/28 20:57:41 grumbel Exp $
 //
 //  Construo - A wire-frame construction game
 //  Copyright (C) 2002 Ingo Ruhnke <grumbel@gmx.de>
@@ -381,7 +381,8 @@ World::update (float delta)
 
   // Remove any springs that are marked as destroyed
   // FIXME: Could be faster
-  for (SpringIter i = springs.begin (); i != springs.end ();)
+  SpringIter i = springs.begin ();
+  while ( i != springs.end ())
     {
       if ((*i)->destroyed)
         {
@@ -512,8 +513,8 @@ World::remove_particle (Particle* p)
 void
 World::remove_spring (Spring* s)
 {
-  std::cout << "particles: " << particle_mgr->size () << std::endl;
-  std::cout << "springs:   " << springs.size () << std::endl;
+  //std::cout << "particles: " << particle_mgr->size () << std::endl;
+  //std::cout << "springs:   " << springs.size () << std::endl;
 
   delete s;
   springs.erase(std::remove(springs.begin (), springs.end (), s), 
