@@ -1,4 +1,4 @@
-//  $Id: x11_display.cxx,v 1.41 2003/07/26 14:55:48 grumbel Exp $
+//  $Id: x11_display.cxx,v 1.46 2003/07/28 22:46:48 grumbel Exp $
 //
 //  Construo - A wire-frame construction game
 //  Copyright (C) 2002 Ingo Ruhnke <grumbel@gmx.de>
@@ -17,6 +17,7 @@
 //  along with this program; if not, write to the Free Software
 //  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
+#include <config.h>
 #include <iostream>
 #include <X11/Xutil.h>
 #include <X11/cursorfont.h>
@@ -38,7 +39,6 @@
 #include "cursor_collider_mask.xbm"
 
 #include "construo_error.hxx"
-#include "config.h"
 #include "x11_display.hxx"
 #include "settings.hxx"
 #include "construo_main.hxx"
@@ -49,29 +49,16 @@
 extern ConstruoMain* construo_main;
 Atom wm_delete_window;
 
-static char zoom_tool_cursor[] = {
-  /* -------- -------- */  0x00,
-  /* -------- -------- */  0x00,
-  /* ------xx xx------ */  0x18,                         
-  /* ----xxxx xxxx---- */  0x3c,
-  /* ----xxxx xxxx---- */  0x3c,
-  /* ------xx xx------ */  0x18,
-  /* -------- -------- */  0x00,
-  /* -------- -------- */  0x00,
-  /* -------- -------- */  0x00,
-  /* -------- -------- */  0x00,
-  /* ------xx xx------ */  0x18,                         
-  /* ----xxxx xxxx---- */  0x3c,
-  /* ----xxxx xxxx---- */  0x3c,
-  /* ------xx xx------ */  0x18,
-  /* -------- -------- */  0x00,
-  /* -------- -------- */  0x00
-};
-
 X11Display::X11Display(int w, int h, bool fullscreen_)
   : doublebuffer (settings.doublebuffer),
     width(w), height(h), shift_pressed (false), fullscreen (fullscreen_)
 {
+#ifndef HAVE_LIBXXF86VM
+  fullscreen_ = false;
+  std::cout << "X11Display: libXxf86vm missing, fullscreen support not\n"
+            << "            available, please recompile." << std::endl;
+#endif
+
   std::cout << "Opening X11 display" << std::endl;
   display = XOpenDisplay(NULL);
 
@@ -164,7 +151,17 @@ X11Display::X11Display(int w, int h, bool fullscreen_)
                  &gcv);
 
   if (fullscreen)
-    set_fullscreen();
+    enter_fullscreen();
+
+  {
+    // Visual* visual = XDefaultVisual(display, DefaultScreen(display));
+    depth = DefaultDepth(display, DefaultScreen(display));
+    if (depth != 16 && depth != 32)
+      {
+        std::cout << "X11Display: Warring color depth '" << depth 
+                  << "' not supported, Construo will be slow!" << std::endl;
+      }
+  }
 
   {
     // Black&White
@@ -172,7 +169,7 @@ X11Display::X11Display(int w, int h, bool fullscreen_)
     XColor cursor_bg = get_xcolor(Color(0, 0, 0));
       
     cursor_scroll_pix = XCreateBitmapFromData (display, window, (char*)cursor_scroll_bits, 
-                                           cursor_scroll_width, cursor_scroll_height);
+                                               cursor_scroll_width, cursor_scroll_height);
     cursor_scroll_mask = XCreateBitmapFromData (display, window, (char*)cursor_scroll_mask_bits, 
                                                 cursor_scroll_width, cursor_scroll_height);
     cursor_scroll = XCreatePixmapCursor(display, cursor_scroll_pix, cursor_scroll_mask, &cursor_bg, &cursor_fg, 
@@ -217,7 +214,7 @@ X11Display::~X11Display ()
   if (fullscreen)
     {
       std::cout << "X11Display: Restoring video mode" << std::endl;
-      restore_mode ();
+      leave_fullscreen ();
     }
   
   if (doublebuffer)
@@ -275,8 +272,8 @@ X11Display::draw_circles(std::vector<Circle>& circles, Color color)
   std::vector<XArc> arcs (circles.size());
   for (std::vector<Circle>::size_type i = 0; i < circles.size(); ++i)
     {
-      arcs[i].x = static_cast<short>(circles[i].x - circles[i].r);
-      arcs[i].y = static_cast<short>(circles[i].y - circles[i].r);
+      arcs[i].x      = static_cast<short>(circles[i].x - circles[i].r);
+      arcs[i].y      = static_cast<short>(circles[i].y - circles[i].r);
       arcs[i].width  = static_cast<short>(2 * circles[i].r);
       arcs[i].height = static_cast<short>(2 * circles[i].r);
       arcs[i].angle1 = 0;
@@ -472,6 +469,10 @@ X11Display::read_event ()
             send_button_press(BUTTON_ACTIONCAM);
             break;
 
+          case XK_s:
+            send_button_press(BUTTON_SCALE);
+            break;
+              
           case XK_j:
             send_button_press(BUTTON_JOIN);
             break;
@@ -723,9 +724,12 @@ X11Display::save_mode()
 }
 
 void
-X11Display::set_fullscreen ()
+X11Display::enter_fullscreen ()
 {
-#ifdef HAVE_LIBXXF86VM
+#ifndef HAVE_LIBXXF86VM
+  std::cout << "X11Display: libXxf86vm missing, fullscreen support not\n"
+            << "            available, please recompile." << std::endl;
+#else
   int event_base;
   int error_base;
 
@@ -837,7 +841,7 @@ X11Display::run()
 
       if (Controller::instance()->is_running())
         {
-          system_context->sleep (0); // limit CPU usage via brute force
+          system_context->sleep (0); // FIXME: limit CPU usage via brute force
           wait_for_events();
         }
       else
@@ -850,16 +854,16 @@ X11Display::run()
 void
 X11Display::toggle_fullscreen()
 {
-  std::cout << "Fullscreen state: " << fullscreen << std::endl;
+  //std::cout << "Fullscreen state: " << fullscreen << std::endl;
 
   if (fullscreen)
-    restore_mode();
+    leave_fullscreen();
   else
-    set_fullscreen();
+    enter_fullscreen();
 }
 
 void
-X11Display::restore_mode ()
+X11Display::leave_fullscreen()
 {
 #ifdef HAVE_LIBXXF86VM
   std::cout << "X11Display::restore_mode()" << std::endl;
@@ -912,15 +916,27 @@ X11Display::set_clip_rect (int x1, int y1, int x2, int y2)
 unsigned int
 X11Display::get_color_value(const Color& color)
 {
-  XColor x_color;
+  switch (depth)
+    {
+    case 32:
+      // FIXME Cast evil?!
+      return static_cast<unsigned int>(color.get_as_rrggbb());
+    case 16:
+      return int(31 * color.b) | (int((63 * color.g)) << 5) | (int((31 * color.r)) << 11);
+    default:
+      { // This is extremly slow!
+        XColor x_color;
 
-  x_color.red   = int(color.r * 65535);
-  x_color.green = int(color.g * 65535);
-  x_color.blue  = int(color.b * 65535);
+        x_color.red   = int(color.r * 65535);
+        x_color.green = int(color.g * 65535);
+        x_color.blue  = int(color.b * 65535);
 
-  XAllocColor(display, colormap, &x_color);
+        XAllocColor(display, colormap, &x_color);
 
-  return x_color.pixel;
+        return x_color.pixel;
+      }
+      break;
+    }
 }
 
 XColor
